@@ -130,7 +130,7 @@ void ssl_init_Module(server_rec *s, pool *p)
     /*
      * Let us cleanup on restarts and exists
      */
-    ap_register_cleanup(p, s, ssl_init_ModuleKill, ssl_init_ModuleKill);
+    ap_register_cleanup(p, s, ssl_init_ModuleKill, ap_null_cleanup);
 
     /*
      * Any init round fixes the global config
