@@ -1,8 +1,8 @@
 /*                      _             _
-**  _ __ ___   ___   __| |    ___ ___| |
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |
-** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to OpenSSL
-** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
+**  _ __ ___   ___   __| |    ___ ___| |  mod_ssl
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |  Apache Interface to OpenSSL
+** | | | | | | (_) | (_| |   \__ \__ \ |  www.modssl.org
+** |_| |_| |_|\___/ \__,_|___|___/___/_|  ftp.modssl.org
 **                      |_____|
 **  ssl_engine_io.c
 **  I/O Functions
@@ -27,7 +27,7 @@
  *    software must display the following acknowledgment:
  *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
- *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
+ *     mod_ssl project (http://www.modssl.org/)."
  *
  * 4. The names "mod_ssl" must not be used to endorse or promote
  *    products derived from this software without prior written
@@ -42,7 +42,7 @@
  *    acknowledgment:
  *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
- *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
+ *     mod_ssl project (http://www.modssl.org/)."
  *
  * THIS SOFTWARE IS PROVIDED BY RALF S. ENGELSCHALL ``AS IS'' AND ANY
  * EXPRESSED OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
@@ -94,9 +94,9 @@ void ssl_io_register(void)
     ap_hook_register("ap::buff::writev", ssl_io_hook_writev, AP_HOOK_NOCTX);
 #endif
 #ifdef WIN32
-    ap_hook_register("ap::buff::recvwithtimeout", 
+    ap_hook_register("ap::buff::recvwithtimeout",
                      ssl_io_hook_recvwithtimeout, AP_HOOK_NOCTX);
-    ap_hook_register("ap::buff::sendwithtimeout", 
+    ap_hook_register("ap::buff::sendwithtimeout",
                      ssl_io_hook_sendwithtimeout, AP_HOOK_NOCTX);
 #endif
     return;
@@ -405,7 +405,7 @@ static int SSL_writev(SSL *ssl, const struct iovec *iov, int iovcnt)
 
 #define DUMP_WIDTH 16
 
-static void ssl_io_data_dump(server_rec *srvr, char *s, long len)
+static void ssl_io_data_dump(server_rec *srvr, const char *s, long len)
 {
     char buf[256];
     char tmp[64];
@@ -453,7 +453,7 @@ static void ssl_io_data_dump(server_rec *srvr, char *s, long len)
     return;
 }
 
-long ssl_io_data_cb(BIO *bio, int cmd, char *argp, int argi, long argl, long rc)
+long ssl_io_data_cb(BIO *bio, int cmd, const char *argp, int argi, long argl, long rc)
 {
     SSL *ssl;
     conn_rec *c;
@@ -465,15 +465,15 @@ long ssl_io_data_cb(BIO *bio, int cmd, char *argp, int argi, long argl, long rc)
         return rc;
     s = c->server;
 
-    if (   cmd == (BIO_CB_WRITE|BIO_CB_RETURN) 
+    if (   cmd == (BIO_CB_WRITE|BIO_CB_RETURN)
         || cmd == (BIO_CB_READ |BIO_CB_RETURN) ) {
         if (rc >= 0) {
             ssl_log(s, SSL_LOG_DEBUG,
                     "%s: %s %ld/%d bytes %s BIO#%08X [mem: %08lX] %s",
-                    SSL_LIBRARY_NAME, 
+                    SSL_LIBRARY_NAME,
                     (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "write" : "read"),
                     rc, argi, (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "to" : "from"),
-                    bio, argp, 
+                    bio, argp,
                     (argp != NULL ? "(BIO dump follows)" : "(Ops, no memory buffer?)"));
             if (argp != NULL)
                 ssl_io_data_dump(s, argp, rc);
@@ -481,7 +481,7 @@ long ssl_io_data_cb(BIO *bio, int cmd, char *argp, int argi, long argl, long rc)
         else {
             ssl_log(s, SSL_LOG_DEBUG,
                     "%s: I/O error, %d bytes expected to %s on BIO#%08X [mem: %08lX]",
-                    SSL_LIBRARY_NAME, argi, 
+                    SSL_LIBRARY_NAME, argi,
                     (cmd == (BIO_CB_WRITE|BIO_CB_RETURN) ? "write" : "read"),
                     bio, argp);
         }
