@@ -1597,6 +1597,7 @@ int ssl_callback_NewSessionCacheEntry(SSL *ssl, SSL_SESSION *pNew)
     server_rec *s;
     SSLSrvConfigRec *sc;
     long t;
+    BOOL rc;
 
     /*
      * Get Apache context back through OpenSSL context
@@ -1616,13 +1617,14 @@ int ssl_callback_NewSessionCacheEntry(SSL *ssl, SSL_SESSION *pNew)
      * Store the SSL_SESSION in the inter-process cache with the
      * same expire time, so it expires automatically there, too.
      */
-    ssl_scache_store(s, pNew, t);
+    rc = ssl_scache_store(s, pNew, t);
 
     /*
      * Log this cache operation
      */
     ssl_log(s, SSL_LOG_TRACE, "Inter-Process Session Cache: "
-            "request=SET id=%s timeout=%ds (session caching)",
+            "request=SET status=%s id=%s timeout=%ds (session caching)",
+            rc == TRUE ? "OK" : "BAD",
             ssl_scache_id2sz(pNew->session_id, pNew->session_id_length),
             t-time(NULL));
 
